@@ -417,6 +417,7 @@ class StoragePoolDriver(object):
     FILE = "FILE"
     FILEThin = "FILE_THIN"
     SPDK = "SPDK"
+    REMOTE_SPDK = "REMOTE_SPDK"
     OPENFLEX_TARGET = "OPENFLEX_TARGET"
     EXOS = "EXOS"
 
@@ -431,6 +432,7 @@ class StoragePoolDriver(object):
             StoragePoolDriver.FILE,
             StoragePoolDriver.FILEThin,
             StoragePoolDriver.SPDK,
+            StoragePoolDriver.REMOTE_SPDK,
             StoragePoolDriver.OPENFLEX_TARGET,
             StoragePoolDriver.EXOS
         ]
@@ -1799,7 +1801,7 @@ class SnapshotDefinition(RESTMessageResponse):
         :return:
         :rtype: list[str]
         """
-        return self._rest_data["nodes"]
+        return self._rest_data.get("nodes", [])
 
     @property
     def flags(self):
@@ -2114,7 +2116,7 @@ class ExosEnclosure(RESTMessageResponse):
 
     @property
     def health_reason(self):
-        return self._rest_data["health_reason"]
+        return self._rest_data.get("health_reason")
 
 
 class ExosListResponse(RESTMessageResponse):
